# Lesty

A CLI tool to execute AWS Lambda handlers with a JSON event file.

## Installation

Install as a development dependency in your Python project:


```bash
poetry add --group=dev lesty
```

## Usage
```sh
poetry run lesty /path/to/lambda_handler.py /path/to/event.json
```
